const path = require("path");
const TerserPlugin = require("terser-webpack-plugin");
const MiniCssExtractPlugin = require("mini-css-extract-plugin");

const modulePath = path.join(__dirname, "./");

const config = {
  entry: {
    "onpoint-search": "/js/onpoint-search.js",
    "onpoint-predict": "/js/onpoint-predict.js",
    "onpoint-suggest": ["/js/onpoint-suggest.js", "/sass/onpoint-suggest.scss"],
    "onpoint-serp": "/js/onpoint-serp.js",
    "onpoint-serp-fr": "/js/onpoint-serp-fr.js",
  },
  output: {
    filename: "[name].min.js",
    path: modulePath + "/dist/",
  },
  target: ["web", "es5"],
  module: {
    rules: [
      {
        test: /\.js$/,
        use: [
          {
            loader: "babel-loader",
            options: {
              presets: [
                [
                  "@babel/preset-env",
                  // {
                  //   debug: true,
                  //   // useBuiltIns: "usage",
                  //   // corejs: 3,
                  // },
                ],
              ],
            },
          },
        ],
        exclude: /node_modules/,
      },
      {
        test: /\.(sc|c)ss$/,
        use: [
          MiniCssExtractPlugin.loader,
          {
            loader: "css-loader",
            options: {
              importLoaders: 1,
            },
          },
          {
            loader: "postcss-loader",
            options: {
              postcssOptions: {
                plugins: [["autoprefixer"]],
              },
            },
          },
          {
            loader: "sass-loader",
          },
        ],
      },
    ],
  },
  devtool: "source-map",
  plugins: [
    new MiniCssExtractPlugin({
      filename: "[name].min.css",
    }),
  ],
  optimization: {
    minimizer: [new TerserPlugin()],
  },
};

module.exports = config;
